/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.placeholder;

import org.tinygroup.fileresolver.FileResolver;
import org.tinygroup.fileresolver.FileResolverFactory;
import org.tinygroup.fileresolver.impl.FileResolverImpl;
import org.tinygroup.fileresolver.impl.I18nFileProcessor;
import org.tinygroup.fileresolver.impl.SpringBeansFileProcessor;
import org.tinygroup.fileresolver.impl.XStreamFileProcessor;
import org.tinygroup.placeholder.fileresolver.PlaceholderDefinedFileProcessor;
import org.tinygroup.placeholder.fileresolver.PlaceholderValidatorFileProcessor;
import org.tinygroup.placeholder.fileresolver.ToBeProcessFileProcessor;
import org.tinygroup.placeholder.fileresolver.WarFileProcessor;

/**
 * 主函数加载类
 * 
 * @author renhui
 * 
 */
public class MainLoad {

	private FileResolver fileResolver;
	private FileResolver warFileResolver;

	//add by ZhaoZ 实现fileResolver的两次扫描；第一次解出所有的war文件，第二次扫描实现文件替换功能；
	MainLoad() {
		fileResolver = FileResolverFactory.getFileResolver();
		warFileResolver = new FileResolverImpl();
	}

	void startResolver(String processorFolder, String fileSuffix,
			String placeholderProperties) {
		//添加扫描路径到fileResolver
		String[] paths = processorFolder.split(",");
		for (String path : paths) {
			fileResolver.addManualClassPath(path);
		}
		String[] propfiles = placeholderProperties.split(",");
		for (String propfile : propfiles) {
			fileResolver.addManualClassPath(propfile);
		}

		//添加扫描路径到warFileResolver
		for (String path : paths) {
			warFileResolver.addManualClassPath(path);
		}
		for (String propfile : propfiles) {
			warFileResolver.addManualClassPath(propfile);
		}

		//warfile扫描，解war包到临时目录
		WarFileProcessor warFileProcessor = new WarFileProcessor();
		warFileResolver.addFileProcessor(warFileProcessor);
		warFileResolver.resolve();

		//其他文件扫描		
		fileResolver.addFileProcessor(new I18nFileProcessor());
		fileResolver.addFileProcessor(new XStreamFileProcessor());
		fileResolver.addFileProcessor(new SpringBeansFileProcessor());
		fileResolver.addFileProcessor(new PlaceholderDefinedFileProcessor());
		fileResolver.addFileProcessor(new PlaceholderValidatorFileProcessor());

		ToBeProcessFileProcessor beProcessFileProcessor = new ToBeProcessFileProcessor();
		beProcessFileProcessor.setExtFileNames(fileSuffix);
		fileResolver.addFileProcessor(beProcessFileProcessor);
		fileResolver.resolve();

		//删除warFileResolver造成的临时目录，并重新打war
		warFileProcessor.removeWarFiles();

	}

}
