/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.placeholder.filewriter;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.StringReader;

import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.placeholder.FileWriter;
import org.tinygroup.vfs.FileObject;

public class CommonFileWriter implements FileWriter {

	private static final String FILE_SCHEMA = "file";
	private static final Logger logger = LoggerFactory
			.getLogger(CommonFileWriter.class);

	public String getSchema() {
		return FILE_SCHEMA;
	}

	public void writeFile(FileObject fileObject, String content, String encoding) {

		OutputStream outputStream = null;
		BufferedWriter write = null;
		BufferedReader reader = null;
		try {
			outputStream = fileObject.getOutputStream();
			write = new BufferedWriter(new OutputStreamWriter(outputStream,
					encoding));
			reader = new BufferedReader(new StringReader(content));
			String lines = null;
			while ((lines = reader.readLine()) != null) {
				write.write(lines);
				write.newLine();
			}
		} catch (IOException e) {
			logger.errorMessage(e.getMessage(), e);
		} finally {
			try {

				if (write != null) {
					write.close();
				}
				if (outputStream != null) {
					outputStream.close();
				}
				if (reader != null) {
					reader.close();
				}
			} catch (IOException e) {
				logger.errorMessage("关闭流出错", e);
			}
		}
	}

}
